.. currentmodule:: pvlib


PV temperature models
---------------------

.. autosummary::
   :toctree: ../generated/

   temperature.sapm_cell
   temperature.sapm_module
   temperature.sapm_cell_from_module
   temperature.pvsyst_cell
   temperature.faiman
   temperature.faiman_rad
   temperature.fuentes
   temperature.ross
   temperature.noct_sam
   temperature.prilliman
   pvsystem.PVSystem.get_cell_temperature
   temperature.generic_linear
   temperature.GenericLinearModel

Temperature Model Parameters
^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. currentmodule:: pvlib.temperature
.. autodata:: TEMPERATURE_MODEL_PARAMETERS
   :annotation:
